##
## menu.py
## Login : <glibersat@localhost.localdomain>
## Started on  Wed Jul 20 01:15:11 2005 Guillaume Libersat
## $Id$
## 
## Copyright (C) 2005 Guillaume Libersat
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
## 
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##

import gtk, gobject
from export import *
from preferences import *
from tabgrab import version
from library import LibraryManager

class GenericMenu(gtk.VBox):
    def __init__(self, ui_info, entries):
        gtk.VBox.__init__(self, 2, False)

        merge = gtk.UIManager()
        merge.insert_action_group(self.__create_action_group(entries), 0)

        try:
            mergeid = merge.add_ui_from_string(ui_info)
        except gobject.GError, msg:
            print "building menus failed: %s" % msg

        # Add menu and toolbar to vbox
        menu = merge.get_widget("/MenuBar")
        if menu:
            self.pack_start(menu)

        toolbar = merge.get_widget("/ToolBar")
        if toolbar:
            toolbar.set_tooltips(True)
            self.pack_start(toolbar)

        self.ui = merge

    def activate_action(self, action):
        print 'Action "%s" activated' % action.get_name()

    def __create_action_group(self, entries):
        # Create the menubar and toolbar
        action_group = gtk.ActionGroup("AppWindowActions")
        action_group.add_actions(entries)

        return action_group


class MainMenu(GenericMenu):
    def __init__(self, window=None):
        ui_info = \
        '''
        <ui>
         <menubar name='MenuBar'>
             <menu action='FileMenu'>
                 <menuitem action='Quit'/>
             </menu>
             <menu action='EditMenu'>
              <menuitem action='Preferences'/>
             </menu>
             <menu action='HelpMenu'>
                 <menuitem action='About'/>
             </menu>
         </menubar>
        </ui>
        '''
         
        # GtkActionEntry
        entries = (
          ( "FileMenu", None, "_File" ),               # name, stock id, label
          ( "EditMenu", None, "_Edit" ),               # name, stock id, label
          ( "HelpMenu", None, "_Help" ),               # name, stock id, label
          
          ( "Quit", gtk.STOCK_QUIT,                    # name, stock id
            "_Quit", "<control>Q",                     # label, accelerator
            "Quit",                                    # tooltip
            self.activate_action ),
          
          ( "Preferences", gtk.STOCK_PREFERENCES,
            "_Preferences", "<control>P",        
            "Edit your preferences",             
            self.activate_preferences ),
          
          ( "About", gtk.STOCK_ABOUT,
            "_About", "<control>A",  
            "About",                 
            self.activate_action )
        );

        GenericMenu.__init__(self, ui_info, entries)

        self.topwin = window

    def activate_action(self, action):
        if action.get_name() == "About":
            dialog = gtk.AboutDialog()
            dialog.set_name("TabGrab")
            dialog.set_version(version)
            dialog.set_copyright("\302\251 Copyright 2005 Guillaume Libersat")
            dialog.set_comments("A little software to find, retrieve and manage tabs.")
            dialog.set_license("This software is copyrighted under the GNU GPL v2.")
            dialog.set_website("http://glibersat.linux62.org/")
            dialog.connect ("response", lambda d, r: d.destroy())
            dialog.show()

        elif action.get_name() == "Quit":
            gtk.main_quit()

    def activate_preferences(self, action):
        win = PreferencesWindow()
        win.show_all()

class ViewWindowMenu(GenericMenu):
    def __init__(self, local=0):
        ui_info = \
        '''
        <ui>
         <toolbar name='ToolBar'>
          <toolitem action='Close'/>
          <separator/>'''
        if local:
            ui_info += \
            '''<toolitem action='Remove'/>'''
        else:
            ui_info += \
            '''<toolitem action='Add'/>'''
            
         
        ui_info += \
        '''<toolitem action='Export'/>
          <separator/>
          <toolitem action='Print'/>
         </toolbar>
        </ui>'''
         
        # GtkActionEntry
        entries = (
            ( "FileMenu", None, "_File" ),              # name, stock id, label
            
            ( "Close", gtk.STOCK_CLOSE,                 # name, stock id
              "_Close", "<control>W",                   # label, accelerator
              "Close this window",                      # tooltip
              self.activate_close ),
            
            ( "Export", gtk.STOCK_SAVE_AS,
              "_Export", "<control>E",
              "Export this tab",
              self.activate_export ),
            
            ( "Add", gtk.STOCK_ADD,
              "_Add to library", "<control>A",
              "Add this tab to tabgrab library",
              self.activate_add ),

            ( "Remove", gtk.STOCK_REMOVE,
              "_Remove", "<control>A",
              "Remove this tab from tabgrab library",
              self.activate_remove),
            
            ( "Print", gtk.STOCK_PRINT,
              "_Print", "<control>P",
              "Print this tab",
              self.activate_print )
            );

        GenericMenu.__init__(self, ui_info, entries)

    def activate_close(self, action):
        self.get_toplevel().destroy()

    def activate_export(self, action):
        # Here, we take tabinfo from topwin, that's not good
        exp = ExportTab(self.get_toplevel().tabinfo)
        ret = exp.run()

        
        if ret == 1:
            uri = exp.get_filename()
            buff = self.get_toplevel().tabview.get()
            exp.export(buff, uri)
            
        exp.destroy()

    def activate_add(self, action):
        lm = LibraryManager()
        tabinfo = self.get_toplevel().tabinfo
        tab = self.get_toplevel().tab
        lm.save(tabinfo, tab)

        self.get_toplevel().library_needs_update = 1

    def activate_remove(self, action):

        dialog = gtk.MessageDialog(self.get_toplevel(),
                            gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
                            gtk.MESSAGE_QUESTION,
                            gtk.BUTTONS_YES_NO,
                            "Would you really like to remove this tab from library ?"
                            )
        
        res = dialog.run()
        dialog.destroy()

        if res == gtk.RESPONSE_YES:
            lm = LibraryManager()
            tabinfo = self.get_toplevel().tabinfo
            lm.delete(tabinfo)

            self.get_toplevel().library_needs_update = 1
            self.get_toplevel().destroy()


    def activate_print(self, action):
        print "Function not implemented"
