##
## result.py
## Login : <glibersat@localhost.localdomain>
## Started on  Tue Jul 19 15:38:42 2005 Guillaume Libersat
## $Id$
## 
## Copyright (C) 2005 Guillaume Libersat
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
## 
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##

import gtk, gobject

from viewwindow import *

( 
  COLUMN_ARTIST,
  COLUMN_TITLE,
  COLUMN_VERSION,
  COLUMN_TYPE,
  COLUMN_NOTE,
  COLUMN_SOURCE,
  COLUMN_RECORDT,
  COLUMN_USERSTR
  ) = range(8)

class ResultTree(gtk.TreeView):
    def __init__(self):
        gtk.TreeView.__init__(self, self.__create_model())
        
        self.set_search_column(COLUMN_TITLE)
        self.set_rules_hint(True) # Alternate colors on list
        
        self.__add_columns()
        
        # Set callback when user click on a result (can choose on at a time)
        sel = self.get_selection()
        sel.set_mode(gtk.SELECTION_SINGLE)

        # If user hit return, space, etc
        self.connect("row-activated", self.__open_tab)

    def __add_columns(self):
        model = self.get_model()


        ## Artist
        column = gtk.TreeViewColumn("Artist", gtk.CellRendererText(), text=COLUMN_ARTIST)
        column.set_sort_column_id(COLUMN_ARTIST)
        self.append_column(column)

        ## Title
        column = gtk.TreeViewColumn("Title", gtk.CellRendererText(), text=COLUMN_TITLE)
        column.set_sort_column_id(COLUMN_TITLE)
        self.append_column(column)

        ## Version
        column = gtk.TreeViewColumn("Version", gtk.CellRendererText(), text=COLUMN_VERSION)
        column.set_sort_column_id(COLUMN_VERSION)
        self.append_column(column)

        ## Type
        column = gtk.TreeViewColumn("Type", gtk.CellRendererText(), text=COLUMN_TYPE)
        column.set_sort_column_id(COLUMN_TYPE)
        self.append_column(column)

        ## Note
        column = gtk.TreeViewColumn("Note", gtk.CellRendererText(), text=COLUMN_NOTE)
        column.set_sort_column_id(COLUMN_NOTE)
        self.append_column(column)

        ## Source
        column = gtk.TreeViewColumn("Source", gtk.CellRendererText(), text=COLUMN_SOURCE)
        column.set_sort_column_id(COLUMN_SOURCE)
        self.append_column(column)
        

    def __create_model(self):
        lstore = gtk.ListStore(
            gobject.TYPE_STRING, # artist
            gobject.TYPE_STRING, # title
            gobject.TYPE_STRING, # version
            gobject.TYPE_STRING, # type
            gobject.TYPE_STRING, # note
            gobject.TYPE_STRING, # source
            gobject.TYPE_STRING, # Record type
            gobject.TYPE_STRING  # User string
            )

        return lstore


    def update(self, data):
        model = self.get_model()
        model.clear()

        if data != None:
            for item in data:
                iter = model.append()
                model.set(iter,
                          COLUMN_ARTIST, item[COLUMN_ARTIST],
                          COLUMN_TITLE, item[COLUMN_TITLE],
                          COLUMN_VERSION, item[COLUMN_VERSION],
                          COLUMN_TYPE, item[COLUMN_TYPE],
                          COLUMN_NOTE, item[COLUMN_NOTE],
                          COLUMN_SOURCE, item[COLUMN_SOURCE],
                          COLUMN_RECORDT, item[COLUMN_RECORDT],
                          COLUMN_USERSTR, item[COLUMN_USERSTR]
                          )

    def __open_tab(self, path, view_column, user):
        selection = self.get_selection()
        
        model, iter = selection.get_selected()
        
        if iter:
            artist = model.get_value(iter, COLUMN_ARTIST)
            title = model.get_value(iter, COLUMN_TITLE)
            version = model.get_value(iter, COLUMN_VERSION)
            type = model.get_value(iter, COLUMN_TYPE)
            note = model.get_value(iter, COLUMN_NOTE)
            source = model.get_value(iter, COLUMN_SOURCE)
            recordt = model.get_value(iter, COLUMN_RECORDT)
            userstr = model.get_value(iter, COLUMN_USERSTR)
            
            win = ViewWindow((artist, title, version, type, note, source, recordt, userstr))
            win.connect("unrealize", self.__update_library)
            win.show_all()

    def __update_library(self, widget):
        ''' When our child returns, maybe we need to reload lib
        since he may have removed a tab from lib'''
        
        if widget.library_needs_update:
            self.get_toplevel().main_table.librarysel.refresh()

            # Only reload at screen if we're on local mode
            if self.get_toplevel().main_table.searchbox.is_in_local_mode():
                self.get_toplevel().main_table.librarysel.artist_changed(None)
        

class ResultView(gtk.ScrolledWindow):
    def __init__(self):
        gtk.ScrolledWindow.__init__(self)
        self.set_shadow_type(gtk.SHADOW_ETCHED_IN)
        self.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
        
        self.tree = ResultTree()
        self.add(self.tree)

    def update(self, data):
        self.tree.update(data)
